WaitForTransaction

Enum WaitForTransaction 

#[non_exhaustive]
pub enum WaitForTransaction { IndexedOnNode, Finalized, }
Determines what to wait for after executing a transaction.

Users should almost always use WaitForTransaction::Finalized (the default), as clients may interact with the indexer and not the fullnode directly. Using WaitForTransaction::IndexedOnNode only guarantees the transaction is indexed on the fullnode (meaning you can submit transactions that reference objects created by this transaction), but subsequent queries using the transaction ID can still fail until the transaction is indexed on the indexer.

Variants (Non-exhaustive)

This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.


IndexedOnNode

Indicates that the transaction effects will be usable in subsequent transactions (you can reference objects created by this transaction), and that the transaction itself is indexed on the fullnode.

Warning: This does not guarantee the transaction is indexed on the indexer. Since the client may query the indexer, subsequent queries with this transaction ID may still fail. Prefer WaitForTransaction::Finalized unless you have a specific reason to use this.



Finalized

Indicates that the transaction has been included in a checkpoint, and all queries may include it.